
/* Display text from stdin on empeg's display.

    Copyright (C) 2000 Rex K. Perkins <rexkp@pobox.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

	History:

	 1Sep2000: Initial release.

 */

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>

#include <unistd.h>
#include <sys/mman.h>

#include <sys/ioctl.h>

#include "empeg_misc.h"



#define BLIT(display_fd)        ioctl((display_fd), _IO('d', 0))
#define DISPLAY(display_fd, x)  ioctl((display_fd), _IOW('d', 1, int), (x))

int main(int argc, char *argv[])
{
  int       display_fd;
  caddr_t   display_mapped;
  char      text[200];
  int       line;
  int       col;
  int       char_count;
  int       index;

  display_fd = open("/dev/display", O_RDWR);
  if (display_fd == -1)
  {
      printf("Unable to open /dev/display\n");
      return(255);
  }

  display_mapped = mmap(0,
                        EMPEG_DISPLAY_SIZE_BYTES,
                        PROT_READ | PROT_WRITE,
                        MAP_SHARED,
                        display_fd,
                        0);

  if (display_mapped == (caddr_t) -1)
  {
      printf("Unable to mmap /dev/display\n");
      return(255);
  }

  // Clear mapped display to 'black'.
  memset(display_mapped,0,EMPEG_DISPLAY_SIZE_BYTES);

  char_count = read(STDIN_FILENO, &text, sizeof(text));

  if (char_count > 0)
  {
      line = 0;
      col = 0;
      index = 0;
      while ((index<char_count) && (line<5) )
      {
          if (text[index] == 0x0A)   //LF
          {
              col = 0;
              line++;
          }
          else if (text[index] != 0x0D)   //!CR
          {
              putChar8x8(display_mapped,
                         col,
                         line,
                         true,
                         text[index]);
              col++;
              if (col >= 16)
              {
                  col = 0;
                  line++;
              }
          }
          index++;
      }
  }

  BLIT(display_fd);
  DISPLAY(display_fd, 1);

  munmap(display_mapped, EMPEG_DISPLAY_SIZE_BYTES);
  close(display_fd);

  return 0;
}

